@@ -283,7 +283,7 @@ class KubernetesPodOperator(BaseOperator):
             return {}
 
         ti = context['ti']
-        run_id = getattr(ti, 'run_id') or context['run_id']
+        run_id = context['run_id']
 
         labels = {'dag_id': ti.dag_id, 'task_id': ti.task_id, 'run_id': run_id}
 
